@@ -18,11 +18,17 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <libgupnp/gupnp-control-point.h>
 #include <libgupnp-av/gupnp-av.h>
 #include <string.h>
 #include <stdlib.h>
+#include <locale.h>
 #include <gmodule.h>
+#include <glib/gi18n.h>
 
 #include "gui.h"
 #include "renderer-combo.h"
@@ -31,6 +37,14 @@
 #define MEDIA_RENDERER "urn:schemas-upnp-org:device:MediaRenderer:1"
 #define MEDIA_SERVER "urn:schemas-upnp-org:device:MediaServer:1"
 
+static int upnp_port = 0;
+
+static GOptionEntry entries[] =
+{
+        { "port", 'p', 0, G_OPTION_ARG_INT, &upnp_port, N_("Network PORT to use for UPnP"), "PORT" },
+        { NULL }
+};
+
 static GUPnPContextManager *context_manager;
 
 static void
@@ -61,6 +75,15 @@ dmr_proxy_unavailable_cb (GUPnPControlPoint *cp,
         remove_media_renderer (proxy);
 }
 
+static void
+on_rescan_button_clicked (GtkButton *button,
+                          gpointer user_data)
+{
+        GSSDPResourceBrowser *browser = GSSDP_RESOURCE_BROWSER (user_data);
+
+        gssdp_resource_browser_rescan (browser);
+}
+
 static void
 on_context_available (GUPnPContextManager *context_manager,
                       GUPnPContext        *context,
@@ -68,6 +91,7 @@ on_context_available (GUPnPContextManager *context_manager,
 {
         GUPnPControlPoint *dms_cp;
         GUPnPControlPoint *dmr_cp;
+        GtkButton *button;
 
         dms_cp = gupnp_control_point_new (context, MEDIA_SERVER);
         dmr_cp = gupnp_control_point_new (context, MEDIA_RENDERER);
@@ -89,11 +113,18 @@ on_context_available (GUPnPContextManager *context_manager,
                           G_CALLBACK (dmr_proxy_unavailable_cb),
                           NULL);
 
+        button = get_rescan_button ();
+
         gssdp_resource_browser_set_active (GSSDP_RESOURCE_BROWSER (dms_cp),
                                            TRUE);
         gssdp_resource_browser_set_active (GSSDP_RESOURCE_BROWSER (dmr_cp),
                                            TRUE);
 
+        g_signal_connect (button, "clicked",
+                          G_CALLBACK (on_rescan_button_clicked), dms_cp);
+        g_signal_connect (button, "clicked",
+                          G_CALLBACK (on_rescan_button_clicked), dmr_cp);
+
         /* Let context manager take care of the control point life cycle */
         gupnp_context_manager_manage_control_point (context_manager, dms_cp);
         gupnp_context_manager_manage_control_point (context_manager, dmr_cp);
@@ -104,13 +135,13 @@ on_context_available (GUPnPContextManager *context_manager,
 }
 
 static gboolean
-init_upnp (void)
+init_upnp (int port)
 {
 #if !GLIB_CHECK_VERSION(2, 35, 0)
         g_type_init ();
 #endif
 
-        context_manager = gupnp_context_manager_new (NULL, 0);
+        context_manager = gupnp_context_manager_create (port);
         g_assert (context_manager != NULL);
 
         g_signal_connect (context_manager,
@@ -141,11 +172,29 @@ gint
 main (gint   argc,
       gchar *argv[])
 {
-        if (!init_ui (&argc, &argv)) {
+        GError *error = NULL;
+        GOptionContext *context = NULL;
+
+        setlocale (LC_ALL, "");
+        bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+        textdomain (GETTEXT_PACKAGE);
+
+        context = g_option_context_new (_("- UPnP AV control point"));
+        g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
+        g_option_context_add_group (context, gtk_get_option_group (TRUE));
+
+        if (!g_option_context_parse (context, &argc, &argv, &error)) {
+                g_print (_("Could not parse options: %s\n"), error->message);
+
+                return -4;
+        }
+
+        if (!init_ui ()) {
            return -2;
         }
 
-        if (!init_upnp ()) {
+        if (!init_upnp (upnp_port)) {
            return -3;
         }
 
