@@ -73,7 +73,9 @@ int main (int argc, char *argv[]) {
         GOptionContext *context;
         GSSDPDiscover discover;
 
+#if !GLIB_CHECK_VERSION(2, 35, 0)
         g_type_init ();
+#endif
 
         context = g_option_context_new ("- discover devices using SSDP");
         g_option_context_add_main_entries (context, entries, NULL);
